==> cuidai_plugin-1.1.0.tar.gz: lib/cuidai_plugin.dart <==
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

class CuidaiRoutes {
  CuidaiRoutes._();
  static const String programDecision = "programs.decision";
  static const String programExplorer = "programs.discover";
  static const String programSearch = "programs.search";
  static const String exerciseExplorer = "trainings.discover";
  static const String meditationExplorer = "meditations.discover";
  static const String chatBotLogin = "chatbot?chatbotId=152&title=Vitat";
  static const String chatBot = "chatbot";
}

class CuidaiCommunication {
  Function _onRoute;

  CuidaiCommunication({@required onRoute(String route)}){
    _onRoute = onRoute;
  }

  Future<dynamic> nativeMethodCallHandler(MethodCall call) async {
    switch (call.method) {
      case "route" :
        String route = call.arguments["route"];
        _onRoute(route);
        return true;
      default:
        return false;
    }
  }
}

class CuidaiPlugin {
  static const MethodChannel _channelToNative = MethodChannel('cuidai_plugin');
  static const MethodChannel _channelFromNative = MethodChannel('cuidai_plugin_native');
  static String schema = "vitat://";

  static void initSDK({@required String appName}) async {
    try {
      schema = "${appName.toLowerCase()}://";
      await _channelToNative.invokeMethod('initSDK', {'appName': appName});
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void startCommunication(CuidaiCommunication communication) async {
    if(communication != null){
      _channelFromNative.setMethodCallHandler(communication.nativeMethodCallHandler);
    }
  }

  static void stopCommunication() {
    _channelFromNative.setMethodCallHandler(null);
  }

  static void setUserProperty(String key, {String value}) async {
    try {
      await _channelToNative.invokeMethod('setUserProperty', {
        "key": key,
        "value": value
      });
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void cleanUserProperties() async {
    try {
      await _channelToNative.invokeMethod('cleanUserProperties');
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void route({@required String deepLink, Map<String, String> params}) async {
    try {
      var route = deepLink.startsWith(schema) ? deepLink : "$schema$deepLink";
      await _channelToNative.invokeMethod('route', {
        "route": route,
        "params": params != null ? params : {}
      });
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void test({@required String route}) async {
    try {
      await _channelToNative.invokeMethod('test', {"route": route});
    } on PlatformException catch (e) {
      print(e.message);
    }
  }
}

==> cuidai_plugin-1.1.4.tar.gz: lib/cuidai_plugin.dart <==
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

class CuidaiRoutes {
  CuidaiRoutes._();
  static const String programDecision = "programs.decision";
  static const String programExplorer = "programs.discover";
  static const String programSearch = "programs.search";
  static const String exerciseExplorer = "trainings.discover";
  static const String meditationExplorer = "meditations.discover";
  static const String chatBotLogin = "chatbot?chatbotId=152&title=Vitat";
  static const String chatBot = "chatbot";
}

class CuidaiCommunication {
  Function _onRoute;

  CuidaiCommunication({@required onRoute(String route)}){
    _onRoute = onRoute;
  }

  Future<dynamic> nativeMethodCallHandler(MethodCall call) async {
    switch (call.method) {
      case "route" :
        String route = call.arguments["route"];
        _onRoute(route);
        return true;
      default:
        return false;
    }
  }
}

class CuidaiPlugin {
  static const MethodChannel _channelToNative = MethodChannel('cuidai_plugin');
  static const MethodChannel _channelFromNative = MethodChannel('cuidai_plugin_native');
  static String schema = "vitat://";

  static void initSDK({@required String appName}) async {
    try {
      schema = "${appName.toLowerCase()}://";
      await _channelToNative.invokeMethod('initSDK', {'appName': appName});
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void startCommunication(CuidaiCommunication communication) async {
    if(communication != null){
      _channelFromNative.setMethodCallHandler(communication.nativeMethodCallHandler);
    }
  }

  static void stopCommunication() {
    _channelFromNative.setMethodCallHandler(null);
  }

  static void setUserProperty(String key, {String value}) async {
    try {
      await _channelToNative.invokeMethod('setUserProperty', {
        "key": key,
        "value": value
      });
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void setUserProperties(Map<String, String> properties) async {
    try {
      await _channelToNative.invokeMethod('setUserProperties', {
        "properties": properties,
      });
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void cleanUserProperties() async {
    try {
      await _channelToNative.invokeMethod('cleanUserProperties');
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static void route({@required String deepLink, Map<String, String> params}) async {
    try {
      var route = deepLink.startsWith(schema) ? deepLink : "$schema$deepLink";
      await _channelToNative.invokeMethod('route', {
        "route": route,
        "params": params != null ? params : {}
      });
    } on PlatformException catch (e) {
      print(e.message);
    }
  }
}
